Class: Google::Cloud::SecurityCenterManagement::V1::SimulateSecurityHealthAnalyticsCustomModuleResponse::SimulatedResult

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/securitycentermanagement/v1/security_center_management.rb

Overview

Possible test result.

Instance Attribute Summary collapse

Instance Attribute Details

#error::Google::Rpc::Status

Returns Error encountered during the test.

Note: The following fields are mutually exclusive: error, finding, no_violation. If a field in that set is populated, all other fields in the set will automatically be cleared.

Returns:

  • (::Google::Rpc::Status)

    Error encountered during the test.

    Note: The following fields are mutually exclusive: error, finding, no_violation. If a field in that set is populated, all other fields in the set will automatically be cleared.



798
799
800
801
# File 'proto_docs/google/cloud/securitycentermanagement/v1/security_center_management.rb', line 798

class SimulatedResult
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#finding::Google::Cloud::SecurityCenterManagement::V1::SimulatedFinding

Returns Finding that would be published for the test case if a violation is detected.

Note: The following fields are mutually exclusive: finding, no_violation, error. If a field in that set is populated, all other fields in the set will automatically be cleared.

Returns:

  • (::Google::Cloud::SecurityCenterManagement::V1::SimulatedFinding)

    Finding that would be published for the test case if a violation is detected.

    Note: The following fields are mutually exclusive: finding, no_violation, error. If a field in that set is populated, all other fields in the set will automatically be cleared.



798
799
800
801
# File 'proto_docs/google/cloud/securitycentermanagement/v1/security_center_management.rb', line 798

class SimulatedResult
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#no_violation::Google::Protobuf::Empty

Returns Indicates that the test case does not trigger any violation.

Note: The following fields are mutually exclusive: no_violation, finding, error. If a field in that set is populated, all other fields in the set will automatically be cleared.

Returns:

  • (::Google::Protobuf::Empty)

    Indicates that the test case does not trigger any violation.

    Note: The following fields are mutually exclusive: no_violation, finding, error. If a field in that set is populated, all other fields in the set will automatically be cleared.



798
799
800
801
# File 'proto_docs/google/cloud/securitycentermanagement/v1/security_center_management.rb', line 798

class SimulatedResult
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end