Class: Google::Cloud::SecurityCenterManagement::V1::SimulateSecurityHealthAnalyticsCustomModuleResponse
- Inherits:
-
Object
- Object
- Google::Cloud::SecurityCenterManagement::V1::SimulateSecurityHealthAnalyticsCustomModuleResponse
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/securitycentermanagement/v1/security_center_management.rb
Overview
Response message for SecurityCenterManagement.SimulateSecurityHealthAnalyticsCustomModule.
Defined Under Namespace
Classes: SimulatedResult
Instance Attribute Summary collapse
-
#result ⇒ ::Google::Cloud::SecurityCenterManagement::V1::SimulateSecurityHealthAnalyticsCustomModuleResponse::SimulatedResult
Result for test case in the corresponding request.
Instance Attribute Details
#result ⇒ ::Google::Cloud::SecurityCenterManagement::V1::SimulateSecurityHealthAnalyticsCustomModuleResponse::SimulatedResult
Returns Result for test case in the corresponding request.
777 778 779 780 781 782 783 784 785 786 787 788 789 790 791 792 793 794 795 796 797 798 799 800 801 802 |
# File 'proto_docs/google/cloud/securitycentermanagement/v1/security_center_management.rb', line 777 class SimulateSecurityHealthAnalyticsCustomModuleResponse include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Possible test result. # @!attribute [rw] finding # @return [::Google::Cloud::SecurityCenterManagement::V1::SimulatedFinding] # Finding that would be published for the test case if a violation is # detected. # # Note: The following fields are mutually exclusive: `finding`, `no_violation`, `error`. If a field in that set is populated, all other fields in the set will automatically be cleared. # @!attribute [rw] no_violation # @return [::Google::Protobuf::Empty] # Indicates that the test case does not trigger any violation. # # Note: The following fields are mutually exclusive: `no_violation`, `finding`, `error`. If a field in that set is populated, all other fields in the set will automatically be cleared. # @!attribute [rw] error # @return [::Google::Rpc::Status] # Error encountered during the test. # # Note: The following fields are mutually exclusive: `error`, `finding`, `no_violation`. If a field in that set is populated, all other fields in the set will automatically be cleared. class SimulatedResult include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |